@@ -39,6 +39,23 @@ class Interaktion:
             actions["{}".format(poi_name)] = readActions(
                 interaktion_dict["Aktion"])
 
+        elif interaction_typ == "Verzweigung":
+            actions["{}_weg".format(poi_name)] = readActions(interaktion_dict["Weg"]
+                                                               + [("Return", "{}_WEG".format(poi_name.upper()))])
+            actions["{}_tipp".format(poi_name)] = readActions(
+                interaktion_dict["Tipp"])
+
+            for aktion, aktion_list in interaktion_dict.items():
+                if aktion.startswith("trigger_"):
+                    weiter_dict = dict((x, y) for x, y in interaktion_dict[aktion.replace("trigger_", "Next_")])
+                    option_next_interaktion = "{}_{}".format(
+                        weiter_dict["POI"], weiter_dict["Aktion"])
+                    action_requirements.append(option_next_interaktion)
+
+                    states["{}_WEG".format(poi_name.upper())] += readTriggers(
+                        aktion_list, option_next_interaktion)
+
+
         elif interaction_typ == "Datenabfrage":
             actions["{}_frage".format(poi_name)] = readActions(interaktion_dict["Frage"]
                                                                + [("Return", "{}_FRAGE".format(poi_name.upper()))])
@@ -50,7 +67,7 @@ class Interaktion:
                     "action": "{}_tipp".format(poi_name)}]
 
         elif interaction_typ == "Weg":
-            return Weg().from_excel_dict(excel_dict_item)
+            return Weg(poi_name, interaktion_dict)
 
         elif interaction_typ == "Quizfrage":
             actions["{}_frage".format(poi_name)] = readActions(
